"""Constants for the Jellyfin APIs."""

from enum import StrEnum


class ItemType(StrEnum):
    """The type of an object in Jellyfin."""

    AggregateFolder = "AggregateFolder"
    Audio = "Audio"
    AudioBook = "AudioBook"
    BasePluginFolder = "BasePluginFolder"
    Book = "Book"
    BoxSet = "BoxSet"
    Channel = "Channel"
    ChannelFolderItem = "ChannelFolderItem"
    CollectionFolder = "CollectionFolder"
    Episode = "Episode"
    Folder = "Folder"
    Genre = "Genre"
    ManualPlaylistsFolder = "ManualPlaylistsFolder"
    Movie = "Movie"
    LiveTvChannel = "LiveTvChannel"
    LiveTvProgram = "LiveTvProgram"
    MusicAlbum = "MusicAlbum"
    MusicArtist = "MusicArtist"
    MusicGenre = "MusicGenre"
    MusicVideo = "MusicVideo"
    Person = "Person"
    Photo = "Photo"
    PhotoAlbum = "PhotoAlbum"
    Playlist = "Playlist"
    PlaylistsFolder = "PlaylistsFolder"
    Program = "Program"
    Recording = "Recording"
    Season = "Season"
    Series = "Series"
    Studio = "Studio"
    Trailer = "Trailer"
    TvChannel = "TvChannel"
    TvProgram = "TvProgram"
    UserRootFolder = "UserRootFolder"
    UserView = "UserView"
    Video = "Video"
    Year = "Year"


class ImageType(StrEnum):
    """The type of an image in Jellyfin."""

    Primary = "Primary"
    Art = "Art"
    Backdrop = "Backdrop"
    Banner = "Banner"
    Logo = "Logo"
    Thumb = "Thumb"
    Disc = "Disc"
    Box = "Box"
    Screenshot = "Screenshot"
    Menu = "Menu"
    Chapter = "Chapter"
    BoxRear = "BoxRear"
    Profile = "Profile"


class ItemFields(StrEnum):
    """Additional fields of information to return in the output."""

    AirTime = "AirTime"
    CanDelete = "CanDelete"
    CanDownload = "CanDownload"
    ChannelInfo = "ChannelInfo"
    Chapters = "Chapters"
    Trickplay = "Trickplay"
    ChildCount = "ChildCount"
    CumulativeRunTimeTicks = "CumulativeRunTimeTicks"
    CustomRating = "CustomRating"
    DateCreated = "DateCreated"
    DateLastMediaAdded = "DateLastMediaAdded"
    DisplayPreferencesId = "DisplayPreferencesId"
    Etag = "Etag"
    ExternalUrls = "ExternalUrls"
    Genres = "Genres"
    HomePageUrls = "HomePageUrl"
    ItemCounts = "ItemCounts"
    MediaSourceCount = "MediaSourceCount"
    MediaSources = "MediaSources"
    OriginalTitle = "OriginalTitle"
    Overview = "Overview"
    ParentId = "ParentId"
    Path = "Path"
    People = "People"
    PlayAccess = "PlayAccess"
    ProductionLocations = "ProductionLocations"
    ProviderIds = "ProviderIds"
    PrimaryImageAspectRatio = "PrimaryImageAspectRatio"
    RecursiveItemCount = "RecursiveItemCount"
    Settings = "Settings"
    ScreenshotImageTags = "ScreenshotImageTags"
    SeriesPrimaryImage = "SeriesPrimaryImage"
    SeriesStudio = "SeriesStudio"
    SortName = "SortName"
    SpecialEpisodeNumbers = "SpecialEpisodeNumbers"
    Studios = "Studios"
    Taglines = "Taglines"
    Tags = "Tags"
    RemoteTrailers = "RemoteTrailers"
    MediaStreams = "MediaStreams"
    SeasonUserData = "SeasonUserData"
    ServiceName = "ServiceName"
    ThemeSongIds = "ThemeSongIds"
    ThemeVideoIds = "ThemeVideoIds"
    ExternalEtag = "ExternalEtag"
    PresentationUniqueKey = "PresentationUniqueKey"
    InheritedParentalRatingValue = "InheritedParentalRatingValue"
    ExternalSeriesId = "ExternalSeriesId"
    SeriesPresentationUniqueKey = "SeriesPresentationUniqueKey"
    DateLastRefreshed = "DateLastRefreshed"
    DateLastSaved = "DateLastSaved"
    RefreshState = "RefreshState"
    ChannelImage = "ChannelImage"
    EnableMediaSourceDisplay = "EnableMediaSourceDisplay"
    Width = "Width"
    Height = "Height"
    ExtraIds = "ExtraIds"
    LocalTrailerCount = "LocalTrailerCount"
    IsHD = "IsHD"
    SpecialFeatureCount = "SpecialFeatureCount"


class ItemFilter(StrEnum):
    """Additional filters."""

    IsFolder = "IsFolder"
    IsNotFolder = "IsNotFolder"
    IsUnplayed = "IsUnplayed"
    IsPlayed = "IsPlayed"
    IsFavorite = "IsFavorite"
    IsResumable = "IsResumable"
    Likes = "Likes"
    Dislikes = "Dislikes"
    IsFavoriteOrLikes = "IsFavoriteOrLikes"


class LocationType(StrEnum):
    """Media location types."""

    FileSystem = "FileSystem"
    Remote = "Remote"
    Virtual = "Virtual"
    Offline = "Offline"


class MediaProtocol(StrEnum):
    """Media protocol."""

    File = "File"
    Http = "Http"
    Rtmp = "Rtmp"
    Rtsp = "Rtsp"
    Udp = "Udp"
    Rtp = "Rtp"
    Ftp = "Ftp"


class MediaSourceType(StrEnum):
    """Media source type."""

    Default = "Default"
    Grouping = "Grouping"
    Placeholder = "Placeholder"
